@@ -5,10 +5,12 @@
 DB='default'
 cAlias='|'
 kAbove='above'
+kArgs='args'
 kCast='as_number'
 kCols='cols'
 kDoc='+doc'
 kExt='file_ext'
+kFunc='function'
 kGroup='group'
 kInner='inner'
 kJoinType='join_type'
